@@ -30,3 +30,5 @@ from .test_protocol_chimera_operate import *
 from .test_protocol_modeller_search import *
 from .test_protocol_contact import TestChimeraContact
 from .test_protocol_chimera_map_subtraction import TestChimeraSubtractMap
+from .test_alpha_fold import TestChimeraAlphafoldImport
+from .test_objects import TestPAE
